.. microvenv documentation master file, created by
   sphinx-quickstart on Thu Sep 21 12:34:20 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

microvenv
=====================================

A package to help create and utilize minimal virtual environments.

- `Repository <https://github.com/brettcannon/microvenv>`__
- `PyPI <https://pypi.org/project/microvenv/>`__

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   api
   cli



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
